@@ -13,7 +13,7 @@ def test():
     if log.is_file():
         os.remove(log)  # pragma: no cover
     response = client.post("/send-notification/foo@example.com?q=some-query")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"message": "Message sent"}
     with open("./log.txt") as f:
         assert "found query: some-query\nmessage to foo@example.com" in f.read()
