@@ -26,11 +26,11 @@ openapi_schema = {
 
 def test_openapi_schema():
     response = client.get("/openapi.json")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == openapi_schema
 
 
 def test_get():
     response = client.get("/")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.text == "Hello World"
