@@ -7,5 +7,5 @@ client = TestClient(app)
 
 def test_get():
     response = client.get("/typer", allow_redirects=False)
-    assert response.status_code == 307
+    assert response.status_code == 307, response.text
     assert response.headers["location"] == "https://typer.tiangolo.com"
