@@ -31,14 +31,14 @@ openapi_schema = {
 
 def test_openapi_schema():
     response = client.get("/openapi.json")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == openapi_schema
     response = client.get("/openapi.json")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == openapi_schema
 
 
 def test():
     response = client.get("/items/")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == [{"name": "Foo"}]
